@@ -32,9 +32,7 @@ class BaseTCPGateway(Gateway):
             self.tcp_disconnect_timer + 2 * self.tasks.transport.reconnect_timeout
         ) < time.time():
             self.tcp_disconnect_timer = time.time()
-            raise OSError(
-                "No response from {}. Disconnecting".format(self.server_address)
-            )
+            raise OSError(f"No response from {self.server_address}. Disconnecting")
         if (
             self.tcp_check_timer + self.tasks.transport.reconnect_timeout
         ) >= time.time():
@@ -52,7 +50,7 @@ class BaseTCPGateway(Gateway):
         self.tcp_disconnect_timer = time.time()
         return None
 
-    def get_gateway_id(self):
+    def _get_gateway_id(self):
         """Return a unique id for the gateway."""
         host, _ = self.server_address
         try:
@@ -75,6 +73,10 @@ class TCPGateway(BaseSyncGateway, BaseTCPGateway):
         transport = SyncTransport(self, sync_connect, **kwargs)
         super().__init__(transport, *args, **kwargs)
 
+    def get_gateway_id(self):
+        """Return a unique id for the gateway."""
+        return self._get_gateway_id()
+
 
 def sync_connect(transport):
     """Connect to socket. This should be run in a new thread."""
@@ -142,7 +144,7 @@ class AsyncTCPGateway(BaseAsyncGateway, BaseTCPGateway):
 
     async def get_gateway_id(self):
         """Return a unique id for the gateway."""
-        mac = await self.tasks.loop.run_in_executor(None, super().get_gateway_id)
+        mac = await self.tasks.loop.run_in_executor(None, self._get_gateway_id)
         return mac
 
 
